@@ -32,10 +32,7 @@ class CommandCaller:
         return self.ts3audiobot.request("song")
 
     def set_volume(self, volume):
-        if 0 >= int(volume) <= 100:
-            return self.ts3audiobot.request("volume/{int}".format(int=volume))
-        else:
-            return False
+        return self.ts3audiobot.request("volume/{int}".format(int=volume))
 
     def stop(self):
         return self.ts3audiobot.request("stop")
